import numpy as np
from pyTurbulence.poissonSolver import poisson_3d

def test_poisson():
    # Define a more complex 3D source term
    nx, ny, nz = 64,64,64
    hx, hy, hz = 1.0, 1.0, 1.0
    x = np.linspace(-1.0, 1.0, nx)
    y = np.linspace(-1.0, 1.0, ny)
    
    f = np.zeros((nx, ny, nz))
    for i in range(nx):
        for j in range(ny):
            for k in range(nz):
                f[i,j,k] = -8.*np.pi**2*np.sin(2.*np.pi * x[i]) * np.sin(2.*np.pi * y[j])
    
    # Compute the solution to the Poisson equation
    pressure = poisson_3d(f, nx, ny, nz, 2.*hx/nx, 2.*hy/ny, 2.*hz/nz)

    # Define the expected results
    p_exact = np.zeros((nx, ny, nz))
    for i in range(nx):
        for j in range(ny):
            for k in range(nz):
                p_exact[i,j,k] = np.sin(2.*np.pi * x[i] / hx) * np.sin(2.*np.pi * y[j] / hy)

    # Test the results
    assert np.allclose(pressure, p_exact, rtol=5e-2), "Test failed: The results do not match the expected solution."

test_poisson()